==> bplan-base-globals-1.1.0-0b4347.zip: lang/lv/global.php <==
<?php
/**
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Locales
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */

return [

    'iso-3166-1-alpha-2' => 'lv',
    'language' => 'Latviešu',
    'locale' => 'lv_LV',

    'currency.decimals'        => "2",
    'currency.format.string'   => ':value €',
    'currency.format.negative' => '-:value €',
    'currency.iso4217.alpha'   => 'EUR',
    'currency.iso4217.numeric' => 978,
    'currency.name'            => 'Eiro',
    'currency.subunit.divisor' => 100,
    'currency.subunit.name'    => 'Euro cents',
    'currency.subunit.symbol'  => 'ct',
    'currency.symbol'          => '€',

    'date.format'       => 'd.m.Y',
    'datetime.format'   => 'd.m.Y. H:i',
    'datetime.format+'  => 'd.m.Y. H:i:s',
    'datetime.format-+' => 'd.m.Y. H:i',
    'datetime.format++' => 'd.m.Y. H:i:s',
    'time.format'       => 'H:i',
    'time.format+'      => 'H:i:s',
    'time.format-+'     => 'H:i',
    'time.format++'     => 'H:i:s',

    'number.decimal-point'       => ',',
    'number.thousands-separator' => ' ',

    'text.direction'    => 'ltr',
    'text.orientation'  => 'sideways',
    'text.writing-mode' => 'vertical-rl',

    // -------------------------------------------------------------------

    'action.activate'      => 'Aktivēt',
    'action.add'           => 'Pievienot',
    'action.cancel'        => 'Atcelt',
    'action.cancel-upload' => 'Atcelt augšupielādi',
    'action.change'        => 'Mainīt',
    'action.close'         => 'Aizvērt',
    'action.confirm'       => 'Apstiprināt',
    'action.deactivate'    => 'Deaktivēt',
    'action.delete'        => 'Dzēst',
    'action.edit'          => 'Rediģēt',
    'action.import'        => 'Importēt',
    'action.print'         => 'Drukāt',
    'action.save'          => 'Saglabāt',
    'action.search'        => 'Meklēt',
    'action.sync'          => 'Sinhronizēt',
    'action.upload'        => 'Augšupielādēt failu',
    'action.verify'        => 'Verificēt',
    'action.view'          => 'Skatīt',

    'languages' => [
        'bg' => 'Bulgāru',
        'de' => 'Vācu',
        'en' => 'Angļu',
        'es' => 'Spāņu',
        'fr' => 'Franču',
        'hu' => 'Ungāru',
        'it' => 'Itāļu',
        'lt' => 'Lietuviešu',
        'pl' => 'Poļu',
        'ro' => 'Rumāņu',
        'ru' => 'Krievu',
        'tr' => 'Turku',
        'uk' => 'Ukraiņu',
    ],

    'option.yes' => 'Jā',
    'option.no'  => 'Nē',

    'required-hint'   => 'Lauki ar atzīmi (<span class="required-marker">:marker</span>) ir obligāti',
    'required-marker' => '*',

    'select-option.please-select' => ' -- Lūdzu, izvēlieties -- ',

    'status.active'   => 'Aktīvs',
    'status.expired'  => 'Beidzies',
    'status.inactive' => 'Neaktīvs',
    'status.invalid'  => 'Nederīgs',
    'status.loading'  => 'Ielādē...',
    'status.not-set'  => 'Nav iestatīts',
    'status.valid'    => 'Derīgs',

];

==> bplan-base-globals-1.2.0-009337.zip: lang/lv/global.php <==
<?php
/**
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Locales
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */

return [

    'iso-3166-1-alpha-2' => 'lv',
    'language' => 'Latviešu',
    'locale' => 'lv_LV',

    'currency.decimals'        => "2",
    'currency.format.string'   => ':value €',
    'currency.format.negative' => '-:value €',
    'currency.iso4217.alpha'   => 'EUR',
    'currency.iso4217.numeric' => 978,
    'currency.name'            => 'Eiro',
    'currency.subunit.divisor' => 100,
    'currency.subunit.name'    => 'Euro cents',
    'currency.subunit.symbol'  => 'ct',
    'currency.symbol'          => '€',

    'date.format'       => 'd.m.Y',
    'datetime.format'   => 'd.m.Y. H:i',
    'datetime.format+'  => 'd.m.Y. H:i:s',
    'datetime.format-+' => 'd.m.Y. H:i',
    'datetime.format++' => 'd.m.Y. H:i:s',
    'time.format'       => 'H:i',
    'time.format+'      => 'H:i:s',
    'time.format-+'     => 'H:i',
    'time.format++'     => 'H:i:s',

    'number.decimal-point'       => ',',
    'number.thousands-separator' => ' ',

    'text.direction'    => 'ltr',
    'text.orientation'  => 'sideways',
    'text.writing-mode' => 'vertical-rl',

    // -------------------------------------------------------------------

    'action.activate'      => 'Aktivēt',
    'action.add'           => 'Pievienot',
    'action.cancel'        => 'Atcelt',
    'action.cancel-upload' => 'Atcelt augšupielādi',
    'action.change'        => 'Mainīt',
    'action.close'         => 'Aizvērt',
    'action.confirm'       => 'Apstiprināt',
    'action.deactivate'    => 'Deaktivēt',
    'action.delete'        => 'Dzēst',
    'action.edit'          => 'Rediģēt',
    'action.import'        => 'Importēt',
    'action.print'         => 'Drukāt',
    'action.save'          => 'Saglabāt',
    'action.search'        => 'Meklēt',
    'action.sync'          => 'Sinhronizēt',
    'action.upload'        => 'Augšupielādēt failu',
    'action.verify'        => 'Verificēt',
    'action.view'          => 'Skatīt',

    'languages' => [
        'bg' => 'Bulgāru',
        'de' => 'Vācu',
        'en' => 'Angļu',
        'es' => 'Spāņu',
        'fr' => 'Franču',
        'hu' => 'Ungāru',
        'it' => 'Itāļu',
        'lt' => 'Lietuviešu',
        'pl' => 'Poļu',
        'ro' => 'Rumāņu',
        'ru' => 'Krievu',
        'tr' => 'Turku',
        'uk' => 'Ukraiņu',
    ],

    'option.yes' => 'Jā',
    'option.no'  => 'Nē',

    'required-hint'   => 'Lauki ar atzīmi (<span class="required-marker">:marker</span>) ir obligāti',
    'required-marker' => '*',

    'select-option.no-options-available' => 'Nav pieejamu opciju',
    'select-option.please-select'        => ' -- Lūdzu, izvēlieties -- ',

    'status.active'   => 'Aktīvs',
    'status.expired'  => 'Beidzies',
    'status.inactive' => 'Neaktīvs',
    'status.invalid'  => 'Nederīgs',
    'status.loading'  => 'Ielādē...',
    'status.not-set'  => 'Nav iestatīts',
    'status.valid'    => 'Derīgs',

];
